@@ -1,7 +1,7 @@
 package File::Serialize::Serializer::YAML::XS;
 our $AUTHORITY = 'cpan:YANICK';
 #ABSTRACT: YAML:XS serializer for File::Serialize
-$File::Serialize::Serializer::YAML::XS::VERSION = '1.3.0';
+$File::Serialize::Serializer::YAML::XS::VERSION = '1.4.0';
 use strict;
 use warnings;
 
@@ -38,7 +38,7 @@ File::Serialize::Serializer::YAML::XS - YAML:XS serializer for File::Serialize
 
 =head1 VERSION
 
-version 1.3.0
+version 1.4.0
 
 =head1 DESCRIPTION
 
@@ -60,6 +60,10 @@ L<YAML::XS>
 
 none
 
+If you have problems with utf8, pass the option C<<utf => 0>>
+to C<serialize_file>/C<deserialize_file>. Or if you use C<transerialize>,
+pass C<utf8=0> as the first argument.
+
 =back
 
 =head1 AUTHOR
@@ -68,7 +72,7 @@ Yanick Champoux <yanick@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2017, 2016, 2015 by Yanick Champoux.
+This software is copyright (c) 2021, 2019, 2017, 2016, 2015 by Yanick Champoux.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
